from datetime import datetime

__title__ = 'laueagle'
__version__ = '0.0.2',
__author__ = 'Liqiang Lau'
__author_email__ = 'liqianglau@outlook.com'
__license__ = 'MIT'
__copyright__ = '(c) {}'.format(datetime.now().year)
__url__ = 'https://liqiang.io/opensource/python/laueagle'
__description__ = """
A data serialization format tools
"""
